function comp_MISE_june14(n)

% Input:
% n = sample size

NTR = 100;                          %no. of trials
p = 100;                            %total no. of predictors
vec_om = [0 0.75];                  %
vec_sigma = [sqrt(8) sqrt(0.2)];    %controls SNR 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Models (definitions as in Sancetta 2016):
% model 1:   low-dimensional model
% model 2:   high-dimensional small equal coefficients
% model 3:   high-dimensional decaying coefficients
% model 4:   high-dimensional slowly decaying coefficients
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Cases are the same as in Sancetta 2016

%Main folder
folder_name = strcat('./SimulationResults/Results_n_',num2str(n));

%Main loop
for model=1:4,
    fprintf('Model %i:\n', model);
    
    for Case=1:3,
        fprintf('Case %i:\n', Case);
        MISE = zeros(2,2,23);
       
        for ind_om = 1:length(vec_om),
            fprintf('omega %3.2f:\n', vec_om(ind_om));
            omega0 = vec_om(ind_om);
            
            for tr=1:NTR,
                fprintf('.');
                if rem(tr,25)==0,
                    fprintf('\n');
                end
                
                %Generate X for prediction               
                [theta, T] = get_T_theta(Case,n);
                X_out = genX(10*n,p,T,theta,omega0);
                %Transform  data
                for jj = 1:p,
                    X_out(:,jj) = X_out(:,jj) - mean(X_out(:, jj));
                    X_out(:,jj) = sqrt(10*n)*( X_out(:,jj)/norm(X_out(:,jj)) );
                end
                
                for ind_sig=1:length(vec_sigma),
                    sigma0 = vec_sigma(ind_sig);
   
                    fname = strcat(folder_name, ...
                        '/Model_',num2str(model), ...
                        '/Case_',num2str(Case), ...
                        '/Omega_', num2str(ind_om), ...
                        '_Sig_', num2str(ind_sig), ...
                        '_Tr_', num2str(tr), ...
                        '.mat');
                    

                     load(fname);
                     if sigma_true~=sigma0, 
                        fprintf('ERROR: sigma!\n');
                     end
                     if omega~=omega0, 
                        fprintf('ERROR: omega!\n');
                     end
                   %  clear vec_err_n vec_df sigma_true nu omega vec_combr ptrue
                     
                     for ind=1:size(ITC,1),
                        [~,w] = min(ITC(ind,:));
                        betahat = Matbeta(:,w);
                        err_out = X_out*betatrue - X_out*betahat;
                        MISE(ind_om,ind_sig,ind) = MISE(ind_om,ind_sig,ind) + mean(err_out.^2 );
                     end %ind
                     
                     cvbetahat = Matbeta(:,cvstep);
                     err_out = X_out*betatrue - X_out*cvbetahat;
                     MISE(ind_om,ind_sig,23) = MISE(ind_om,ind_sig,23) + mean(err_out.^2 );
            
                end %ind_sig
        
            end %tr
    
        end %ind_om

        MISE = MISE/NTR;
        
        fname2 = strcat(folder_name, ...
                        '/Model_',num2str(model), ...
                        '/Case_',num2str(Case), ...
                        '/MISE', ...
                        '.mat');             
        save(fname2, 'MISE');
        
    end % Case
   
end % Model

end %function


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [theta, T] = get_T_theta(Case,n)

if Case == 1,
    T       = 0;
    theta   = 1;
elseif Case == 2,
    T       =  100 + n;
    theta   =  0.95.^(0:T); 
elseif Case == 3,
    T       =  1000 + n;
    theta   = (1:T+1).^(-1/2); 
else
end

end %function

