function [X, Maty, betatrue, ptrue] = gendata(n,model,Case,p,vec_sigma,omega)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Input:
% n             = no. of samples
% model         = 1 or 2 or 3 or 4
% Case          = 1 or 2 or 3
% p             = total number of predictors
% vec_sigma     = controls SNR
% omega         = 0 or 0.75

%Output:
% X            = full dictionary
% Maty         = response vectors
% betatrue     = true linear coefficients
% ptrue        = true no. of predictors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%four models
if model==1,
     ptrue = 3;
     betatrue = [1/3*ones(ptrue,1); zeros(p-ptrue,1)];
elseif model==2,
     ptrue = p;
     betatrue = (1/p)*ones(p,1);
elseif model==3,
     ptrue = p;
     betatrue = (1./(1:p))';
elseif model==4,
     ptrue = p;
     betatrue = ((1:p).^(-1/2))';
else
    fprintf('ERROR: model\n');
    return;
end

%three cases
if Case == 1,
    T       = 0;
    theta   = 1;
elseif Case == 2,
    T       =  100 + n;
    theta   =  0.95.^(0:T); 
elseif Case == 3,
    T       =  1000 + n;
    theta   = (1:T+1).^(-1/2); 
else
    fprintf('ERROR: Case\n');
    return;
end

%generate X
X = genX(n,p,T,theta,omega);

ytrue = X*betatrue;
Maty = zeros(n,length(vec_sigma));

%generate \veps_{i,0}
if T==0,
    eps = randn(n,1);
else
    eps = filter(theta,1,randn(T+n,1));
    eps = eps(T+1:end);
end
kappa = sqrt(  var(ytrue)/var(eps) );

%generate data
for ind_sig=1:length(vec_sigma),    
    sigma = vec_sigma(ind_sig);  
    Z = (kappa/sigma)*eps;
    Maty(:,ind_sig) = ytrue + Z;
end %sigma

end %function




