function run_exp_sance_june14(n)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Input:
% n = sample size
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
NTR = 100;                          %no. of trials
p = 100;                            %total no. of predictors
vec_om = [0 0.75];                  %
vec_sigma = [sqrt(8) sqrt(0.2)];    %controls SNR 
nu = 0.1;                           %param for greediness
mub = 20000;                        %upper bound no. iterations

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Models (definitions as in Sancetta 2016):
% model 1:   low-dimensional model
% model 2:   high-dimensional small equal coefficients
% model 3:   high-dimensional decaying coefficients
% model 4:   high-dimensional slowly decaying coefficients
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Cases are the same as in Sancetta 2016

%Create folders for saving the results
folder_name = strcat('./SimulationResults/Results_n_',num2str(n));
[suc,~,~] = mkdir(folder_name);
if suc==0,
    return;
end
%%%%%%%%%%%%%%%%%%%%%%!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
for model = 1:4
    extra = strcat('Model_',num2str(model));
    [suc,~,~] = mkdir(folder_name,extra);
    if suc==0,
        return;
    end
    folder_name2 = strcat(folder_name,'/',extra);
    for Case=1:3,
        extra2 = strcat('Case_',num2str(Case));
        [suc,~,~] = mkdir(folder_name2,extra2);
        if suc==0,
            return;
        end
    end
end



%Main loop
for model=1:4,

    fprintf('Model %i:\n', model);
    
   for Case=1:3,

        fprintf('Case %i:\n', Case);
        
        for ind_om = 1:length(vec_om),
            fprintf('omega %3.2f:\n', vec_om(ind_om));
            omega = vec_om(ind_om);
            
            for tr=1:NTR,
                fprintf('.');
                if rem(tr,25)==0,
                    fprintf('\n');
                end
                
                %Generate data
                [X, Maty, betatrue, ptrue] = gendata(n,model,Case,p,vec_sigma,omega);
                
    
                for ind_sig=1:length(vec_sigma),
                    sigma_true = vec_sigma(ind_sig);
                    y = Maty(:,ind_sig);
                
                    [Matbeta, vec_err_n, vec_df, ITC, vec_combr, vec_combd] = mpa_june14( y, X, mub, nu );
                     [cv,cvstep] = CV( y, X, mub, nu);
                    
                    fname = strcat(folder_name, ...
                        '/Model_',num2str(model), ...
                        '/Case_',num2str(Case), ...
                        '/Omega_', num2str(ind_om), ...
                        '_Sig_', num2str(ind_sig), ...
                        '_Tr_', num2str(tr), ...
                        '.mat');

                     
                     save(fname, 'Matbeta', 'vec_err_n', 'vec_df', ...
                         'ITC', 'sigma_true', 'nu', 'omega', ...
                         'betatrue', 'vec_combr', 'ptrue', 'vec_combd','cv','cvstep');
            
                end %ind_sig
        
            end %tr
    
        end %ind_om

    end % Case

end % Model

end %function